==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Enviar");
define("_URL","Link");
define("_PRINTER","Imprimir");
define("_FRIEND","Envie esta histria a um amigo");
define("_YOURNAME","Seu Nome");
define("_OK","Ok!");
define("_RELATED","Links Relacionados");
define("_MOREABOUT","Mais Sobre");
define("_NEWSBY","Notcias por");
define("_MOSTREAD","As histrias mais lidas sobre");
define("_READMORE","Leia Mais...");
define("_BYTESMORE","Mais bytes");
define("_COMMENTSQ","comentrios?");
define("_COMMENT","comentrio");
define("_CONFIGURE","Configurar");
define("_LOGINCREATE","Login/Criar uma Conta");
define("_THRESHOLD","Comeo");
define("_NOCOMMENTS","Sem Comentrios");
define("_NESTED","Alojados");
define("_FLAT","Plano");
define("_THREAD","Discusso");
define("_OLDEST","Velho Primeiro");
define("_NEWEST","Novo Primeiro");
define("_HIGHEST","Pontuao Alta Primeiro");
define("_COMMENTSWARNING","Os comentrios so propriedade de quem os escreveu. Ns no somos responsveis por seu contedo.");
define("_SCORE","Pontos:");
define("_USERINFO","Informaes do Usurios");
define("_READREST","Ler o resto deste comentrio...");
define("_REPLY","Responder a Este");
define("_REPLYMAIN","Enviar Comentrio");
define("_NOSUBJECT","Sem Ttulo");
define("_NOANONCOMMENTS","Comentrios no podem ser enviados por usurios annimos por favor <a href=\"modules.php?name=Your_Account\">registre-se</a>");
define("_PARENT","Pai");
define("_ROOT","Raiz");
define("_UCOMMENT","Comentrio");
define("_ALLOWEDHTML","HTML Permitido:");
define("_POSTANON","Enviar como Annimo");
define("_EXTRANS","Usar (comandos de HTML no texto)");
define("_HTMLFORMATED","Formatado em HTML");
define("_PLAINTEXT","Texto Puro");
define("_ONN","em...");
define("_SUBJECT","Ttulo");
define("_COMMENTREPLY","Enviar Comentrio");
define("_COMREPLYPRE","Visualizar Comentrio antes de envia-lo");
define("_NOTRIGHT","Algo est errado se passar est varivel. Est mensagem possui apenas pensamentos para serem publicados em uma rodovia.");
define("_SENDAMSG","Enviar a Mensagem");
define("_YOUSENDSTORY","Voc vai enviar est histria");
define("_TOAFRIEND","a um amigo:");
define("_FYOURNAME","Seu Nome:");
define("_FYOUREMAIL","Seu E-mail:");
define("_FFRIENDNAME","Nome do Seu Amigo:");
define("_FFRIENDEMAIL","E-Mail do Seu Amigo:");
define("_INTERESTING","Artigo Interessante em");
define("_HELLO","Al");
define("_YOURFRIEND","Seu Amigo");
define("_CONSIDERED","achou este artigo interessante e enviou para voc.");
define("_FDATE","Data:");
define("_FTOPIC","Tpico:");
define("_YOUCANREAD","Voc pode ler artigos interessantes em");
define("_FSTORY","Histria");
define("_HASSENT","Foi enviada para");
define("_THANKS","Obrigado!");
define("_RECOMMEND","Indique este site a um amigo");
define("_PDATE","Data:");
define("_PTOPIC","Tpico:");
define("_COMESFROM","Este artigo veio de");
define("_THEURL","O Link desta histria :");
define("_PREVIEW","Pr-Visualizao");
define("_NEWUSER","Novo Usurio");
define("_OPTIONS","Opes");
define("_REFRESH","Atualizar");
define("_ADD","Adicionar");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Enviar");
define("_URL","Link");
define("_PRINTER","Imprimir");
define("_FRIEND","Envie esta histria a um amigo");
define("_YOURNAME","Seu Nome");
define("_OK","Ok!");
define("_RELATED","Links Relacionados");
define("_MOREABOUT","Mais Sobre");
define("_NEWSBY","Notcias por");
define("_MOSTREAD","As histrias mais lidas sobre");
define("_READMORE","Leia Mais...");
define("_BYTESMORE","Mais bytes");
define("_COMMENTSQ","comentrios?");
define("_COMMENT","comentrio");
define("_CONFIGURE","Configurar");
define("_LOGINCREATE","Login/Criar uma Conta");
define("_THRESHOLD","Comeo");
define("_NOCOMMENTS","Sem Comentrios");
define("_NESTED","Alojados");
define("_FLAT","Plano");
define("_THREAD","Discusso");
define("_OLDEST","Velho Primeiro");
define("_NEWEST","Novo Primeiro");
define("_HIGHEST","Pontuao Alta Primeiro");
define("_COMMENTSWARNING","Os comentrios so propriedade de quem os escreveu. Ns no somos responsveis por seu contedo.");
define("_SCORE","Pontos:");
define("_USERINFO","Informaes do Usurios");
define("_READREST","Ler o resto deste comentrio...");
define("_REPLY","Responder a Este");
define("_REPLYMAIN","Enviar Comentrio");
define("_NOSUBJECT","Sem Ttulo");
define("_NOANONCOMMENTS","Comentrios no podem ser enviados por usurios annimos por favor <a href=\"modules.php?name=Your_Account\">registre-se</a>");
define("_PARENT","Pai");
define("_ROOT","Raiz");
define("_UCOMMENT","Comentrio");
define("_ALLOWEDHTML","HTML Permitido:");
define("_POSTANON","Enviar como Annimo");
define("_EXTRANS","Usar (comandos de HTML no texto)");
define("_HTMLFORMATED","Formatado em HTML");
define("_PLAINTEXT","Texto Puro");
define("_ONN","em...");
define("_SUBJECT","Ttulo");
define("_COMMENTREPLY","Enviar Comentrio");
define("_COMREPLYPRE","Visualizar Comentrio antes de envia-lo");
define("_NOTRIGHT","Algo est errado se passar est varivel. Est mensagem possui apenas pensamentos para serem publicados em uma rodovia.");
define("_SENDAMSG","Enviar a Mensagem");
define("_YOUSENDSTORY","Voc vai enviar est histria");
define("_TOAFRIEND","a um amigo:");
define("_FYOURNAME","Seu Nome:");
define("_FYOUREMAIL","Seu E-mail:");
define("_FFRIENDNAME","Nome do Seu Amigo:");
define("_FFRIENDEMAIL","E-Mail do Seu Amigo:");
define("_INTERESTING","Artigo Interessante em");
define("_HELLO","Al");
define("_YOURFRIEND","Seu Amigo");
define("_CONSIDERED","achou este artigo interessante e enviou para voc.");
define("_FDATE","Data:");
define("_FTOPIC","Tpico:");
define("_YOUCANREAD","Voc pode ler artigos interessantes em");
define("_FSTORY","Histria");
define("_HASSENT","Foi enviada para");
define("_THANKS","Obrigado!");
define("_RECOMMEND","Indique este site a um amigo");
define("_PDATE","Data:");
define("_PTOPIC","Tpico:");
define("_COMESFROM","Este artigo veio de");
define("_THEURL","O Link desta histria :");
define("_PREVIEW","Pr-Visualizao");
define("_NEWUSER","Novo Usurio");
define("_OPTIONS","Opes");
define("_REFRESH","Atualizar");
define("_ADD","Adicionar");
define("_NOCOMMENTSACT","Sorry, Comments are not available for this article.");
define("_ARTICLEPOLL","Article's Poll");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
